added timer for recovering missing activation/deactivation replies of bchannels from...
[lcr.git] / mISDN.h
diff --git a/mISDN.h b/mISDN.h
index 47626f1..836947c 100644 (file)
--- a/mISDN.h
+++ b/mISDN.h
@@ -53,6 +53,7 @@ struct mISDNport {
        unsigned long b_addr[128];
 #endif
        int b_state[128]; /* statemachine, 0 = IDLE */
+       double b_timer[128]; /* timer for state machine */
        unsigned long b_remote_id[128]; /* the socket currently exported */
        unsigned long b_remote_ref[128]; /* the ref currently exported */
        int procids[128]; /* keep track of free ids */
@@ -111,7 +112,8 @@ class PmISDN : public Port
        void message_crypt(unsigned long epoint_id, int message_id, union parameter *param);
        struct mISDNport *p_m_mISDNport;        /* pointer to port */
        int p_m_delay;                          /* use delay instead of dejitter */
-       int p_m_txvol, p_m_rxvol;               /* volume shift (0 = no change) */
+       int p_m_tx_gain, p_m_rx_gain;           /* volume shift (0 = no change) */
+       char p_m_pipeline[256];                 /* filter pipeline */
        int p_m_echo, p_m_conf;                 /* remote echo, conference number */
        int p_m_tone;                           /* current kernel space tone */
        int p_m_rxoff;                          /* rx from driver is disabled */